@@ -23,6 +23,9 @@ class defaults(object):
     DEFAULT_MOBILE_FLAVOUR = u'mobile'
     FLAVOURS_TEMPLATE_PREFIX = u''
     FLAVOURS_GET_PARAMETER = u'flavour'
+    FLAVOURS_STORAGE_BACKEND = u'cookie'
+    FLAVOURS_COOKIE_KEY = u'flavour'
+    FLAVOURS_COOKIE_HTTPONLY = False
     FLAVOURS_SESSION_KEY = u'flavour'
     FLAVOURS_TEMPLATE_LOADERS = []
     for loader in django_settings.TEMPLATE_LOADERS:
