@@ -1,4 +1,5 @@
 import re
+from django_mobile import flavour_storage
 from django_mobile import set_flavour, _init_flavour
 from django_mobile.conf import settings
 
@@ -12,6 +13,10 @@ class SetFlavourMiddleware(object):
             if flavour in settings.FLAVOURS:
                 set_flavour(flavour, request, permanent=True)
 
+    def process_response(self, request, response):
+        flavour_storage.save(request, response)
+        return response
+
 
 class MobileDetectionMiddleware(object):
     user_agents_test_match = (
@@ -72,3 +77,5 @@ class MobileDetectionMiddleware(object):
 
         if is_mobile:
             set_flavour(settings.DEFAULT_MOBILE_FLAVOUR, request)
+        else:
+            set_flavour(settings.FLAVOURS[0], request)
